This repo provides a set of schemas to be used by the rqlite-API and other repos that require the schemas.
The schemas are published on pypi ([here](https://pypi.org/project/gjp-models/)) and can be installed like any other package:

1. `pip install gjp-models`
2. Or by adding it to pyproject.toml/setup.[cfg|py]

The schemas are published every time you merge into main. The version is automatically bumped.



